-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

---------------------
-- Prep the module --
---------------------
local M = {}
M.type = "auxilliary"
M.relevantDevice = nil
M.defaultOrder = 11000

-- Parachute state
local lastChuteOn = 0
local lastChuteRez = 0

local max = math.max
local min = math.min

---------------------------------------------
-- Graphics update function                --
-- Updates other stuff too according to dt --
---------------------------------------------
local function updateGFX(dt)
	local chuteOn = (electrics.values.hb9k_parachuteOn or 0)
	local chuteRez = (electrics.values.hb9k_parachuteRez or 0)
	local setNewState = false
	
	if chuteOn ~= lastChuteOn then
		lastChuteOn = chuteOn
		setNewState = true
		if chuteOn <= 0 then
			electrics.values.hb9k_parachuteDriftR = 0
			electrics.values.hb9k_parachuteDriftL = 0
		end
	end
	if chuteRez ~= lastChuteRez then
		lastChuteRez = chuteRez
		setNewState = true
		gui.message("Parachute resistance = " .. tostring(chuteRez * 100) .. "%")		
	end
	if setNewState then
		electrics.values.hb9k_parachuteState = chuteOn * chuteRez - 1
	end
	if chuteOn > 0 then
--		electrics.values.hb9k_parachuteDriftR = chuteRez * (1 - max((electrics.values.steering_input or 0), 0))
--		electrics.values.hb9k_parachuteDriftL = chuteRez * (1 + min((electrics.values.steering_input or 0), 0))
		electrics.values.hb9k_parachuteDriftR = (1 - max((electrics.values.steering_input or 0), 0))
		electrics.values.hb9k_parachuteDriftL = (1 + min((electrics.values.steering_input or 0), 0))
	end
end

-- Reset what we need to
local function reset()
	lastChuteOn = (electrics.values.hb9k_parachuteOn or 0)
	lastChuteRez = (electrics.values.hb9k_parachuteRez or 0)
	electrics.values.hb9k_parachuteElev = 0
	
	-- Debug message
	print("Parachute reset called")
end

-- Initialize everything
local function init(jbeamdata)
	lastChuteOn = (electrics.values.hb9k_parachuteOn or 0)
	lastChuteRez = (electrics.values.hb9k_parachuteRez or 0)
	electrics.values.hb9k_parachuteElev = 0
	
	-- Debug message
	print("Parachute init called")
end

-- Public interface
M.init = init
M.reset = reset
M.updateGFX = updateGFX

-- Return the module
return M
